@@ -14,13 +14,16 @@
 
 """APScheduler implementation."""
 
+import flask
 import functools
 import logging
 import socket
 import warnings
+import werkzeug
 
 from apscheduler.events import EVENT_ALL
 from apscheduler.schedulers.background import BackgroundScheduler
+from apscheduler.jobstores.base import JobLookupError
 from flask import make_response
 from . import api
 from .utils import fix_job_def, pop_trigger
@@ -66,6 +69,11 @@ class APScheduler(object):
         """Get the base scheduler."""
         return self._scheduler
 
+    @property
+    def task(self):
+        """Get the base scheduler decorator"""
+        return self._scheduler.scheduled_job
+
     def init_app(self, app):
         """Initialize the APScheduler with a Flask application instance."""
 
@@ -83,6 +91,12 @@ class APScheduler(object):
         Start the scheduler.
         :param bool paused: if True, don't start job processing until resume is called.
         """
+
+        # Flask in debug mode spawns a child process so that it can restart the process each time your code changes,
+        # the new child process initializes and starts a new APScheduler causing the jobs to run twice.
+        if flask.helpers.get_debug_flag() and not werkzeug.serving.is_running_from_reloader():
+            return
+
         if self.host_name not in self.allowed_hosts and '*' not in self.allowed_hosts:
             LOGGER.debug('Host name %s is not allowed to start the APScheduler. Servers allowed: %s' %
                          (self.host_name, ','.join(self.allowed_hosts)))
@@ -265,7 +279,7 @@ class APScheduler(object):
         job = self._scheduler.get_job(id, jobstore)
 
         if not job:
-            raise LookupError(id)
+            raise JobLookupError(id)
 
         job.func(*job.args, **job.kwargs)
 
